@@ -1,8 +1,8 @@
 from pipetools.utils import foreach
 
-__version__ = VERSION = 0, 1, 4
+__version__ = VERSION = 0, 1, 5
 
 __versionstr__ = VERSION > foreach(str) | '.'.join
 
-from pipetools.main import pipe, X
+from pipetools.main import pipe, X, maybe
 from pipetools.utils import *
