@@ -1,48 +1,15 @@
-from functools import partial, wraps
+from functools import partial
 from itertools import imap, ifilter, islice
 import operator
 
-from pipetools.main import pipe, X, XObject, _iterable, StringFormatter
-from pipetools.ds_builder import data_structure_builder
+from pipetools.main import pipe, X, _iterable
+from pipetools.decorators import pipe_util, auto_string_formatter
+from pipetools.decorators import data_structure_builder
 
 
 KEY, VALUE = X[0], X[1]
 
 
-def pipe_util(func):
-    """
-    Decorator that handles X objects and currying for pipe-utils.
-    """
-    @wraps(func)
-    def pipe_util_wrapper(function, *args, **kwargs):
-        if isinstance(function, XObject):
-            function = ~function
-
-        if args or kwargs:
-            function = partial(function, *args, **kwargs)
-
-        return pipe | func(function)
-
-    return pipe_util_wrapper
-
-
-def auto_string_formatter(func):
-    """
-    Decorator that handles automatic string formatting.
-
-    By converting a string argument to a function that does formatting on said
-    string.
-    """
-    @wraps(func)
-    def auto_string_formatter_wrapper(function, *args, **kwargs):
-        if isinstance(function, basestring):
-            function = StringFormatter(function)
-
-        return func(function, *args, **kwargs)
-
-    return auto_string_formatter_wrapper
-
-
 @pipe_util
 @auto_string_formatter
 @data_structure_builder
@@ -178,7 +145,7 @@ def select_first(condition):
     >>> ['py', 'pie', 'pi'] > select_first(X.startswith('pi'))
     'pie'
     """
-    return lambda seq: unless(StopIteration, where(condition) | X.next(), seq)
+    return where(condition) | unless(StopIteration, X.next())
 
 
 @pipe_util
@@ -197,11 +164,29 @@ def group_by(function):
     return _group_by
 
 
-def unless(exception_class, func, *args, **kwargs):
-    try:
-        return partial(func, *args, **kwargs)()
-    except exception_class:
-        pass
+def unless(exception_class_or_tuple, func, *args, **kwargs):
+    """
+    When `exception_class_or_tuple` occurs while executing `func`, it will
+    be caught and ``None`` will be returned.
+
+    >>> f = where(X > 10) | list | unless(IndexError, X[0])
+    >>> f([5, 8, 12, 4])
+    12
+    >>> f([1, 2, 3])
+    None
+    """
+    @pipe_util
+    @auto_string_formatter
+    @data_structure_builder
+    def construct_unless(function):
+        # a wrapper so we can re-use the decorators
+        def _unless(*args, **kwargs):
+            try:
+                return function(*args, **kwargs)
+            except exception_class_or_tuple:
+                pass
+        return _unless
+    return construct_unless(func, *args, **kwargs)
 
 
 def _flatten(x):
